#
# spec file for package moreutils.spec
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           moreutils
Version:        0.59
Release:        1.1
Summary:        Additional Unix Utilities
License:        GPL-2.0+ and GPL-2.0 and MIT
Group:          System/Management
Url:            http://joeyh.name/code/moreutils/
Source:         %{name}-%{version}.tar.gz
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  libxslt
Requires:       perl
Requires:       perl-TimeDate perl-Time-Duration
# These perl modules add functionality to the ts command, as they are added in eval'd code they are not
# picked up automatically by rpm.
BuildRoot:      %{_tmppath}/%{name}-%{version}-build


%description
This is a growing collection of the Unix tools that nobody thought to write long ago, when Unix was young.

So far, it includes the following utilities:

  - chronic: runs a command quietly unless it fails
  - combine: combine the lines in two files using boolean operations
  - errno: look up errno names and descriptions
  - ifdata: get network interface info without parsing ifconfig output
  - ifne: run a program if the standard input is not empty
  - isutf8: check if a file or standard input is utf-8
  - lckdo: execute a program with a lock held
  - mispipe: pipe two commands, returning the exit status of the first
  - parallel: run multiple jobs at once
  - pee: tee standard input to pipes
  - sponge: soak up standard input and write to a file
  - ts: timestamp standard input
  - vidir: edit a directory in your text editor
  - vipe: insert a text editor into a pipe
  - zrun: automatically uncompress arguments to command

%package parallel
Summary:        Additional unix utility - parallel command
Group:          Applications/System
Requires:       %{name} = %{version}-%{release}
Conflicts:      gnu_parallel

%description parallel
 This is a growing collection of the Unix tools that nobody thought to write long ago, when Unix was young.

 This is a sub package containing the parallel command only

  - parallel: run multiple jobs at once


%prep
%setup -q

%build
export CFLAGS="$RPM_OPT_FLAGS"
export CXXFLAGS="$RPM_OPT_FLAGS"
%if 0%{?suse_version}
export DOCBOOKXSL="/usr/share/xml/docbook/stylesheet/nwalsh/current"
%endif
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_version}
export DOCBOOKXSL="/usr/share/sgml/docbook/xsl-stylesheets"
%endif
make %{?_smp_mflags}
echo "### before install ###"

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
echo "### after install ###"


%files
%defattr(-, root, root)
%doc COPYING README
%attr(644, root, root) %{_mandir}/man1/chronic.1*
%attr(644, root, root) %{_mandir}/man1/combine.1*
%attr(644, root, root) %{_mandir}/man1/errno.1*
%attr(644, root, root) %{_mandir}/man1/ifdata.1*
%attr(644, root, root) %{_mandir}/man1/ifne.1*
%attr(644, root, root) %{_mandir}/man1/isutf8.1*
%attr(644, root, root) %{_mandir}/man1/lckdo.1*
%attr(644, root, root) %{_mandir}/man1/mispipe.1*
%attr(644, root, root) %{_mandir}/man1/pee.1*
%attr(644, root, root) %{_mandir}/man1/sponge.1*
%attr(644, root, root) %{_mandir}/man1/ts.1*
%attr(644, root, root) %{_mandir}/man1/vidir.1*
%attr(644, root, root) %{_mandir}/man1/vipe.1*
%attr(644, root, root) %{_mandir}/man1/zrun.1*
%{_bindir}/chronic
%{_bindir}/combine
%{_bindir}/errno
%{_bindir}/ifdata
%{_bindir}/ifne
%{_bindir}/isutf8
%{_bindir}/lckdo
%{_bindir}/mispipe
%{_bindir}/pee
%{_bindir}/sponge
%{_bindir}/ts
%{_bindir}/vidir
%{_bindir}/vipe
%{_bindir}/zrun

%files parallel
%defattr(-,root,root)
%doc README COPYING
%attr(644, root, root) %{_mandir}/man1/parallel.1.gz
%{_bindir}/parallel

%changelog
* Fri Apr 22 2016 aloisio@gmx.com
- Update to version 0.59
  * Makefile: add DOCBOOKXSL setting.
    Thanks, Kevin Bullock
  * parallel: include signal.h to fix warning when building with clang
    Thanks, Kevin Bullock
  * chronic: Added -v option for more verbose output.
    Thanks, Tomas Mudrunka
  * chronic: Added -e option to display any stderr.
    Thanks, Tomas Mudrunka
  version 0.58:
  * OpenBSD compile fix.
    Thanks, Michael Reed.
  * ts: Quiet perl's complaints about utf-8. Closes: #812143
    Thanks, Nicolas Schier.
- Removed Makefile.patch and Makefile-RHEL.patch and replaced
  them with variable setting
* Tue Jul 28 2015 aloisio@gmx.com
- Update to version 0.57
  * Avoid using non-portable error() in ifdata, a portability
    reversion introduced in 0.56.
  version 0.56:
  * ifdata: Fix error messages when a non-existent network
    interface is queried. Closes: #386754 Thanks, Nicolas Schier
  * errno.docbook: Fix typo. Closes: #749399
  * vidir: Create missing target directories. Closes: #728688
    Thanks, Nicolas Schier
* Sun Feb  8 2015 aloisio@gmx.com
- Update to version 0.55
  * parallel: serialise output through internal pipe.
    Closes: #704125 Thanks, Nicolas Schier.
  * sponge: add append option '-a'.
    Closes: #623197 Thanks, Nicolas Schier.
* Sun Dec 14 2014 aloisio@gmx.com
- Split parallel to a separate package
- Fixed build problem on RHEL
* Fri Dec 12 2014 aloisio@gmx.com
- Update to version 0.54
* Fri Jun  7 2013 Werner Flamme <w.flamme@web.de>
- version 0.48 added to my repo, since no one else provides it
* Sat May  4 2013 Joey Hess <joeyh@debian.org>
- moreutils (0.48) unstable; urgency=low
  * Allow overriding PREFIX and CFLAGS to make the build more flexible
    (Thanks, Ben Walton)
  * Typo. Closes: #697113
  * ts: -i enables incremental timestamping.
    Thanks, Thomas Vander Stichele
  * ts: Support single-digit day dates.
    Thanks, Peter Lunicks
  * sponge: Check fclose to detect certian short reads. Closes: #704453
